import java.util.Scanner;

public class MagicSquareGenerator {
    private int size;
    private int[][] square;

    // Constructor to initialize the magic square
    public MagicSquareGenerator(int size) {
        this.size = size;
        this.square = new int[size][size];
        generateMagicSquare();
    }

    // Generating the magic square using method in coursework brief
    private void generateMagicSquare() {
        int x = 0, y = size / 2;
        for (int i = 1; i <= size * size; i++) {
            square[x][y] = i;
            int newX = (x - 1 + size) % size;
            int newY = (y - 1 + size) % size;

            if (square[newX][newY] == 0) {
                x = newX;
                y = newY;
            } else {
                x = (x + 1) % size;
            }
        }
    }

    // Display the magic square in a formatted grid
    public void display() {
        for (int[] row : square) {
            for (int num : row) {
                System.out.printf("%3d ", num);
            }
            System.out.println();
        }
    }

    public static void main(String[] args) {
        Scanner scanner = new Scanner(System.in);
        int size;

        // Input validation: Ensuring the number is a positive odd integer
        while (true) {
            System.out.print("Enter an odd integer for the magic square size: ");
            if (!scanner.hasNextInt()) {
                System.out.println("Invalid input. Please enter a positive odd integer.");
                // Consume invalid input
                scanner.next();
                continue;
            }
            size = scanner.nextInt();
            if (size % 2 == 1 && size > 0) break;
            System.out.println("Invalid input. Please enter a positive odd integer.");
        }

        // Generate and display the magic square
       	MagicSquareGenerator magicSquare = new MagicSquareGenerator(size);
        System.out.println("\nGenerated Magic Square:");
        magicSquare.display();
    }
}
